<?php

namespace Drupal\cafe_reservation\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Database;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class ReservationController.
 */
class ReservationController extends ControllerBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a ReservationController object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * List of reservations for the current logged-in user.
   */
  public function list() {
    // Get the current user ID.
    $current_user = $this->currentUser();

    // Check if the user is logged in.
    if ($current_user->isAuthenticated()) {
      $user_id = $current_user->id();

      $header = [
        ['data' => $this->t('User')],
        ['data' => $this->t('Reservation Date')],
        ['data' => $this->t('Table Size')],
        ['data' => $this->t('Status')],
      ];

      // Query reservations for the current user only.
      $query = Database::getConnection()->select('cafe_reservations', 'cr')
        ->fields('cr', ['user_id', 'reservation_date', 'table_size', 'status'])
        ->condition('user_id', $user_id);
      $results = $query->execute()->fetchAll();

      $rows = [];
      foreach ($results as $row) {
        $user = $this->entityTypeManager->getStorage('user')->load($row->user_id);
        $rows[] = [
          'data' => [
            $user ? $user->getDisplayName() : $this->t('Anonymous'),
            date('Y-m-d H:i', $row->reservation_date),
            $row->table_size,
            $row->status,
          ],
        ];
      }

      // Return the table with the current user's reservations.
      return [
        '#type' => 'table',
        '#header' => $header,
        '#rows' => $rows,
        '#empty' => $this->t('No reservations found for your account.'),
        '#attributes' => ['class' => ['cafe-reservation-table']],
        '#attached' => [
          'library' => [
            'cafe_reservation/custom_styles',
          ],
        ],
      ];
    }
    else {
      // If the user is not logged in, show an access denied message.
      return [
        '#markup' => $this->t('You must be logged in to view your reservations.'),
      ];
    }
  }

}
